@@ -8,7 +8,7 @@
  */
 
 #include <sm/gen.h>
-SM_IDSTR(id, "@(#)$Id: smstdio.c,v 1.32 2002/02/23 20:18:36 gshapiro Exp $")
+SM_IDSTR(id, "@(#)$Id: smstdio.c,v 1.32.2.2 2003/09/05 20:35:28 ca Exp $")
 #include <unistd.h>
 #include <stdio.h>
 #include <fcntl.h>
@@ -68,6 +68,23 @@ sm_stdioopen(fp, info, flags, rpool)
 	  case SM_IO_APPENDRW:
 		stdiomode = "a+";
 		break;
+#if SM_IO_BINARY != 0
+	  case SM_IO_RDONLY_B:
+		stdiomode = "rb";
+		break;
+	  case SM_IO_WRONLY_B:
+		stdiomode = "wb";
+		break;
+	  case SM_IO_APPEND_B:
+		stdiomode = "ab";
+		break;
+	  case SM_IO_APPENDRW_B:
+		stdiomode = "a+b";
+		break;
+	  case SM_IO_RDWR_B:
+		stdiomode = "r+b";
+		break;
+#endif /* SM_IO_BINARY != 0 */
 	  case SM_IO_RDWR:
 	  default:
 		stdiomode = "r+";
